<?php

namespace App\Http\Livewire;

use Livewire\Component;
use Illuminate\Support\Facades\DB;

class DashboardMod extends Component
{

    public $userId;
    private $monthLabel = array();
    private $hiresNumber = array();

    public function countFranchises()
    {

        $countFranchises = DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->where('rh_agences.AGENCE_NOM', '!=', 'ICC Développement')
            ->count();

        return $countFranchises;
    }

    public function countICCDev()
    {

        $countICCDev = DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->where('rh_agences.AGENCE_NOM', '=', 'ICC Développement')
            ->count();

        return $countICCDev;
    }

    public function lastHires()
    {

        $lastHires = DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->orderBy('rh_employees.EMPLOYEE_DATEARRIVEE', 'desc')
            ->limit(3)
            ->get();

        return $lastHires;
    }

    public function countAgencesFranchisees()
    {

        $countAgencesFranchisees = DB::table('rh_agences')
            ->where('rh_agences.AGENCE_TYPE', '=', 'Franchise')
            ->count();

        return $countAgencesFranchisees;
    }

    public function countAgencesFiliales()
    {

        $countAgencesFiliales = DB::table('rh_agences')
            ->where('rh_agences.AGENCE_TYPE', '=', 'Filiale')
            ->count();

        return $countAgencesFiliales;
    }

    public function countOriasEnCours()
    {

        $countOriasEnCours = DB::table('rh_orias')
            ->where('ORIAS_ETAT', '=', 'EN COURS')
            ->count();

        return $countOriasEnCours;
    }

    public function countOriasAFaire()
    {

        $countOriasAFaire = DB::table('rh_orias')
            ->where('ORIAS_ETAT', '=', NULL)
            ->count();

        return $countOriasAFaire;
    }

    public function countIeamEnCours()
    {

        $countIeamEnCours = DB::table('rh_ieam')
            ->where('IEAM_ETAT', '=', 'EN COURS')
            ->count();

        return $countIeamEnCours;
    }

    public function countIeamAFaire()
    {

        $countIeamAFaire = DB::table('rh_ieam')
            ->where('IEAM_ETAT', '=', NULL)
            ->count();

        return $countIeamAFaire;
    }

    public function countAfibEnCours()
    {

        $countAfibEnCours = DB::table('rh_afib')
            ->where('AFIB_ETAT', '=', 'EN COURS')
            ->count();

        return $countAfibEnCours;
    }

    public function countAfibAFaire()
    {

        $countAfibAFaire = DB::table('rh_afib')
            ->where('AFIB_ETAT', '=', NULL)
            ->count();

        return $countAfibAFaire;
    }

    public function countDevices()
    {

        $countDevices = DB::table('rh_devices')
            ->count();

        return $countDevices;
    }

    public function countDevicesExpiration()
    {

        $date = now();
        $date =  strtotime("-6 month", strtotime($date));
        $date = date('Y/m/d h:i:s', $date);

        $countDevicesExpiration = DB::table('rh_devices')
            ->where('DEVICE_ENROLLEDDATETIME', "<", $date)
            ->count();

        return $countDevicesExpiration;
    }


    public function countLastArrival()
    {

        $countLastArrival = DB::select("SELECT COUNT(*) NB_ARRIVANT , UPPER(DATE_FORMAT(EMPLOYEE_DATEARRIVEE, '%M', 'FR_FR')) MOIS
            FROM RH_EMPLOYEES
            WHERE EMPLOYEE_DATEARRIVEE BETWEEN DATE_ADD(CURRENT_DATE(),INTERVAL -8 MONTH) AND CURRENT_DATE()
            GROUP BY MONTHNAME(EMPLOYEE_DATEARRIVEE)
            ORDER BY EMPLOYEE_DATEARRIVEE ASC
        ");

       foreach ($countLastArrival as $arrival) {
            array_push($this->monthLabel, $arrival->MOIS);
            array_push($this->hiresNumber, $arrival->NB_ARRIVANT);
        }
        
        return ([$countLastArrival,$this->monthLabel,$this->hiresNumber]);
    }

    public function render()
    {

        return view('pages.dashboard-list', [
            'countFranchises' => $this->countFranchises(),
            'countICCDev' => $this->countICCDev(),
            'countAgencesFranchisees' => $this->countAgencesFranchisees(),
            'countAgencesFiliales' => $this->countAgencesFiliales(),
            'countOriasEnCours' => $this->countOriasEnCours(),
            'countOriasAFaire' => $this->countOriasAFaire(),
            'countIeamEnCours' => $this->countIeamEnCours(),
            'countIeamAFaire' => $this->countIeamAFaire(),
            'countAfibEnCours' => $this->countAfibEnCours(),
            'countAfibAFaire' => $this->countAfibAFaire(),
            'countDevices' => $this->countDevices(),
            'countDevicesExpiration' => $this->countDevicesExpiration(),
            'lastHires' => $this->lastHires(),
            'countLastArrival' => $this->countLastArrival(),
            'monthLabel' => $this->monthLabel,
            'hiresNumber' => $this->hiresNumber,
        ]);
    }
}
